==> haskell-hakyll-4.12.5.2-70-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hakyll.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hakyll
version: 4.12.5.2
id: hakyll-4.12.5.2-CwAwKHzALvY1p0ECG1Lx2F
key: hakyll-4.12.5.2-CwAwKHzALvY1p0ECG1Lx2F
license: BSD-3-Clause
maintainer: Jasper Van der Jeugt <m@jaspervdj.be>
author: Jasper Van der Jeugt <m@jaspervdj.be>
homepage: http://jaspervdj.be/hakyll
synopsis: A static website compiler library
description:
    Hakyll is a static website compiler library. It provides you with the tools to
    create a simple or advanced static website using a Haskell DSL and formats
    such as markdown or RST. You can find more information, including a tutorial,
    on the website:
    .
    * <http://jaspervdj.be/hakyll>
    .
    If you seek assistance, there'\''s:
    .
    * A google group: <http://groups.google.com/group/hakyll>
    .
    * An IRC channel, @#hakyll@ on freenode
    .
    Additionally, there'\''s the Haddock documentation in the different modules,
    meant as a reference.
category: Web
abi: bd20db12323910a566613903af1ea957
exposed: True
exposed-modules:
    Hakyll Hakyll.Commands Hakyll.Core.Compiler
    Hakyll.Core.Compiler.Internal Hakyll.Core.Configuration
    Hakyll.Core.Dependencies Hakyll.Core.File Hakyll.Core.Identifier
    Hakyll.Core.Identifier.Pattern Hakyll.Core.Item Hakyll.Core.Logger
    Hakyll.Core.Metadata Hakyll.Core.Provider
    Hakyll.Core.Provider.Metadata Hakyll.Core.Routes Hakyll.Core.Rules
    Hakyll.Core.Rules.Internal Hakyll.Core.Runtime Hakyll.Core.Store
    Hakyll.Core.UnixFilter Hakyll.Core.Util.File
    Hakyll.Core.Util.String Hakyll.Core.Writable Hakyll.Main
    Hakyll.Web.CompressCss Hakyll.Web.Feed Hakyll.Web.Html
    Hakyll.Web.Html.RelativizeUrls Hakyll.Web.Paginate
    Hakyll.Web.Pandoc Hakyll.Web.Pandoc.Biblio
    Hakyll.Web.Pandoc.FileType Hakyll.Web.Redirect Hakyll.Web.Tags
    Hakyll.Web.Template Hakyll.Web.Template.Context
    Hakyll.Web.Template.Internal Hakyll.Web.Template.Internal.Element
    Hakyll.Web.Template.Internal.Trim Hakyll.Web.Template.List
hidden-modules: Data.List.Extended Data.Yaml.Extended Hakyll.Check
                Hakyll.Core.Compiler.Require
                Hakyll.Core.Identifier.Pattern.Internal Hakyll.Core.Item.SomeItem
                Hakyll.Core.Provider.Internal Hakyll.Core.Provider.MetadataCache
                Hakyll.Core.Util.Parser Paths_hakyll Hakyll.Preview.Poll
                Hakyll.Preview.Server Hakyll.Web.Pandoc.Binary
import-dirs: /usr/lib/ghc-8.6.5/site-local/hakyll-4.12.5.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/hakyll-4.12.5.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-hakyll
hs-libraries: HShakyll-4.12.5.2-CwAwKHzALvY1p0ECG1Lx2F
depends:
    base-4.12.0.0 binary-0.8.6.0
    blaze-html-0.9.1.1-Icge9VdFJKdIYmonGkJUKg
    blaze-markup-0.8.2.2-IwLwNWRUxfsEuYbkQ0Gv5Q bytestring-0.10.8.2
    containers-0.6.0.1 cryptohash-0.11.9-OQcbeAGOLeKPBFaG6FtL6
    data-default-0.7.1.1-FxanJFkeYAJQ1iDuwiDPz deepseq-1.4.4.0
    directory-1.3.3.0 file-embed-0.0.11-4IE3sw0bCLQ7xXwEGMUYke
    filepath-1.4.2.1 fsnotify-0.3.0.1-lby5ih3AwXG2FkLWj99ra
    http-conduit-2.3.7.1-CFKsKZuwomNH09NCuA00sO
    http-types-0.12.3-4mvqCFA58Pd9Ot84cA11d5
    lrucache-1.2.0.1-Jp0V4IWXx2qKkaEspf8xgI mtl-2.2.2
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    optparse-applicative-0.14.3.0-93eSEj9ICWNLMTEZg8268q
    pandoc-2.7.3-5SnTkUCJzxeIyZvuaUuhqe
    pandoc-citeproc-0.16.2-4JjparXIv1pLKDc99RQVSe parsec-3.1.13.0
    process-1.6.5.0 random-1.1-3ypV4EIycgb35PKjTYYr5q
    regex-tdfa-1.2.3.2-1zrqdepzFAcLwdkKMIY7hi
    resourcet-1.2.2-8hEDHRutAsl8XBsaHNUdIq
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b
    tagsoup-0.14.8-bQuTxVSfm0MHTKaVRPw4 text-1.2.3.1 time-1.8.0.2
    time-locale-compat-0.1.1.5-4Kz46WDKPmGDmYVdO1w5q7
    unordered-containers-0.2.10.0-1NpUw7eLrexDi5zNhT27CT
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
    wai-3.2.2.1-CQ54CFlyR3DJGjuiF7FXOI
    wai-app-static-3.1.6.3-B4jBNxEplZoHD3OwfmRDrd
    warp-3.3.0-HNNNtujfbUEBHVvZf0zqu0
    yaml-0.11.1.0-LELoYugYmZc16IMCtvMYe4
haddock-interfaces: /usr/share/doc/haskell-hakyll/html/hakyll.haddock
haddock-html: /usr/share/doc/haskell-hakyll/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hakyll-4.12.5.2-92-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hakyll.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hakyll
version: 4.12.5.2
id: hakyll-4.12.5.2-8uIkKA8W2bUJ53iMi46VP0
key: hakyll-4.12.5.2-8uIkKA8W2bUJ53iMi46VP0
license: BSD-3-Clause
maintainer: Jasper Van der Jeugt <m@jaspervdj.be>
author: Jasper Van der Jeugt <m@jaspervdj.be>
homepage: http://jaspervdj.be/hakyll
synopsis: A static website compiler library
description:
    Hakyll is a static website compiler library. It provides you with the tools to
    create a simple or advanced static website using a Haskell DSL and formats
    such as markdown or RST. You can find more information, including a tutorial,
    on the website:
    .
    * <http://jaspervdj.be/hakyll>
    .
    If you seek assistance, there'\''s:
    .
    * A google group: <http://groups.google.com/group/hakyll>
    .
    * An IRC channel, @#hakyll@ on freenode
    .
    Additionally, there'\''s the Haddock documentation in the different modules,
    meant as a reference.
category: Web
abi: da05fbc75df232969d0f98d21d45cafe
exposed: True
exposed-modules:
    Hakyll Hakyll.Commands Hakyll.Core.Compiler
    Hakyll.Core.Compiler.Internal Hakyll.Core.Configuration
    Hakyll.Core.Dependencies Hakyll.Core.File Hakyll.Core.Identifier
    Hakyll.Core.Identifier.Pattern Hakyll.Core.Item Hakyll.Core.Logger
    Hakyll.Core.Metadata Hakyll.Core.Provider
    Hakyll.Core.Provider.Metadata Hakyll.Core.Routes Hakyll.Core.Rules
    Hakyll.Core.Rules.Internal Hakyll.Core.Runtime Hakyll.Core.Store
    Hakyll.Core.UnixFilter Hakyll.Core.Util.File
    Hakyll.Core.Util.String Hakyll.Core.Writable Hakyll.Main
    Hakyll.Web.CompressCss Hakyll.Web.Feed Hakyll.Web.Html
    Hakyll.Web.Html.RelativizeUrls Hakyll.Web.Paginate
    Hakyll.Web.Pandoc Hakyll.Web.Pandoc.Biblio
    Hakyll.Web.Pandoc.FileType Hakyll.Web.Redirect Hakyll.Web.Tags
    Hakyll.Web.Template Hakyll.Web.Template.Context
    Hakyll.Web.Template.Internal Hakyll.Web.Template.Internal.Element
    Hakyll.Web.Template.Internal.Trim Hakyll.Web.Template.List
hidden-modules: Data.List.Extended Data.Yaml.Extended Hakyll.Check
                Hakyll.Core.Compiler.Require
                Hakyll.Core.Identifier.Pattern.Internal Hakyll.Core.Item.SomeItem
                Hakyll.Core.Provider.Internal Hakyll.Core.Provider.MetadataCache
                Hakyll.Core.Util.Parser Paths_hakyll Hakyll.Preview.Poll
                Hakyll.Preview.Server Hakyll.Web.Pandoc.Binary
import-dirs: /usr/lib/ghc-8.6.5/site-local/hakyll-4.12.5.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/hakyll-4.12.5.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-hakyll
hs-libraries: HShakyll-4.12.5.2-8uIkKA8W2bUJ53iMi46VP0
depends:
    base-4.12.0.0 binary-0.8.6.0
    blaze-html-0.9.1.1-4JkTtLEB4Yx9lkhlQlW7SA
    blaze-markup-0.8.2.2-IwLwNWRUxfsEuYbkQ0Gv5Q bytestring-0.10.8.2
    containers-0.6.0.1 cryptohash-0.11.9-CoTMowpthlAFX290whuknU
    data-default-0.7.1.1-5JZ15VDIkjR94TfgciXLrQ deepseq-1.4.4.0
    directory-1.3.3.0 file-embed-0.0.11-4IE3sw0bCLQ7xXwEGMUYke
    filepath-1.4.2.1 fsnotify-0.3.0.1-7Iyw8902uvFRto4XeaNIA
    http-conduit-2.3.7.1-G2w7vWPk1V4DF7fe0f7sBo
    http-types-0.12.3-HC8QVCkRWraINFy4YJ7OYV
    lrucache-1.2.0.1-Jp0V4IWXx2qKkaEspf8xgI mtl-2.2.2
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    optparse-applicative-0.14.3.0-8hy6ZL8cldl8WZw9XYPHX5
    pandoc-2.7.3-FBP4jfRCAamCJTYdPZYsWj
    pandoc-citeproc-0.16.2-BviqMqsYg70CBTx42gmzOg parsec-3.1.13.0
    process-1.6.5.0 random-1.1-3ypV4EIycgb35PKjTYYr5q
    regex-tdfa-1.2.3.2-1zrqdepzFAcLwdkKMIY7hi
    resourcet-1.2.2-JLxEmnu4VEmKsSbOPjgbf0
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b
    tagsoup-0.14.8-DGG11JtHSmWKGlohPlXRaq text-1.2.3.1 time-1.8.0.2
    time-locale-compat-0.1.1.5-4Kz46WDKPmGDmYVdO1w5q7
    unordered-containers-0.2.10.0-8ZCNQorHEnr2Al0NbBIjXw
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
    wai-3.2.2.1-Cf1QznwLY1e38bxndDSCcE
    wai-app-static-3.1.6.3-D3UzEKCcOqL8pqt69ugm0A
    warp-3.3.0-80vy4DlpjpbFRI7GGEYNcd
    yaml-0.11.1.2-GcrC5gzJJYy7QaoJJ7PWya
haddock-interfaces: /usr/share/doc/haskell-hakyll/html/hakyll.haddock
haddock-html: /usr/share/doc/haskell-hakyll/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
